//
//  FollowCreatorViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/19.
//

import Foundation
import Moya
import Combine

final class FollowCreatorViewModel: ObservableObject {
    private let repository = FollowCreatorRepository()
    private var userRepository = UserRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var isLoading = false
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var creatorList = [GetCreatorFollowingAllListItem]()
    
    @Published var totalCount = 0
    
    var page = 1
    var isLast = false
    private let pageSize = 10
    
    func getFollowedCreatorAllList() {
        if (!isLast && !isLoading) {
            isLoading = true
            
            repository.getFollowedCreatorAllList(page: page, size: pageSize)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    self.isLoading = false
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetCreatorFollowingAllListResponse>.self, from: responseData)
                        self.isLoading = false
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                creatorList.removeAll()
                            }
                            
                            self.totalCount = data.totalCount
                            
                            if !data.items.isEmpty {
                                page += 1
                                self.creatorList.append(contentsOf: data.items)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                        self.isLoading = false
                    }
                }
                .store(in: &subscription)
        } else {
            isLoading = false
        }
    }
    
    func creatorFollow(creatorId: Int, index: Int, follow: Bool = true, notify: Bool = true) {
        isLoading = true
        userRepository.creatorFollow(creatorId: creatorId, follow: follow, notify: notify)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        var creator = self.creatorList[index]
                        creator.isFollow = follow
                        creator.isNotify = notify
                        self.creatorList.remove(at: index)
                        self.creatorList.insert(creator, at: index)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
