//
//  ServiceCenterViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/11.
//

import Foundation
import Combine

final class ServiceCenterViewModel: ObservableObject {
    
    private let repository = FaqRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var faqs = [Faq]()
    @Published var categories = [String]()
    @Published var selectedCategory = "" {
        didSet {
            getFaqs()
        }
    }
    
    func getFaqCategories() {
        categories.removeAll()
        isLoading = true
        
        repository.getFaqCategories()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[String]>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.categories.append(contentsOf: data)
                        if !data.isEmpty {
                            self.selectedCategory = data[0]
                        }
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
    
    func getFaqs() {
        faqs.removeAll()
        isLoading = true
        
        repository.getFaqs(category: self.selectedCategory)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[Faq]>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.faqs.append(contentsOf: data)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
